@@ -1,7 +1,7 @@
 #######################################################################
 # This file is part of steve.
 #
-# Copyright (C) 2012, 2013 Will Kahn-Greene
+# Copyright (C) 2012-2014 Will Kahn-Greene
 # Licensed under the Simplified BSD License. See LICENSE for full
 # license.
 #######################################################################
@@ -12,5 +12,5 @@
 # * 1.0a2
 # * 1.0b2
 # * 1.0
-__version__ = '0.2'
-__releasedate__ = '20130317'
+__version__ = '0.3'
+__releasedate__ = '2014-03-17'
