@@ -1,7 +1,7 @@
 #######################################################################
 # This file is part of steve.
 #
-# Copyright (C) 2012, 2013 Will Kahn-Greene
+# Copyright (C) 2012-2014 Will Kahn-Greene
 # Licensed under the Simplified BSD License. See LICENSE for full
 # license.
 #######################################################################
@@ -11,9 +11,11 @@ import ConfigParser
 import datetime
 import json
 import os
+import string
 import sys
 import textwrap
 from functools import wraps
+from urlparse import urlparse
 
 import html2text
 import vidscraper
@@ -35,6 +37,15 @@ YOUTUBE_EMBED = {
     }
 
 
+def is_youtube(url):
+    parsed = urlparse(url)
+    return parsed.netloc.startswith(
+        ('www.youtube.com', 'youtube.com', 'youtu.be'))
+
+
+ALLOWED_LETTERS = string.ascii_letters + string.digits + '-_'
+
+
 class SteveException(Exception):
     """Base steve exception"""
     def __init__(self, *args, **kwargs):
@@ -221,11 +232,19 @@ def convert_to_json(structure):
     return json.dumps(structure, indent=2, sort_keys=True, default=convert)
 
 
+def generate_filename(text):
+    filename = text.replace(' ', '_')
+    filename = ''.join([c for c in filename if c in ALLOWED_LETTERS])
+    filename = '_' + filename
+    return filename
+
+
 def vidscraper_to_dict(video, youtube_embed=None):
     """Converts vidscraper Video to a python dict
 
     :arg video: vidscraper Video
-    :arg youtube_embed: the embed code to use for YouTube videos
+    :arg youtube_embed: the embed code to use for YouTube videos or
+        "object" or "iframe"
 
     :returns: dict
 
@@ -246,7 +265,6 @@ def vidscraper_to_dict(video, youtube_embed=None):
     item['tags'] = video.tags
     item['speakers'] = []
 
-    item['added'] = datetime.datetime.now()
     item['recorded'] = video.publish_datetime
     item['language'] = u'English'
 
@@ -271,13 +289,19 @@ def vidscraper_to_dict(video, youtube_embed=None):
                 item['video_flv_url'] = f.url
                 item['video_flv_download_only'] = False
             else:
-                raise ValueError(
-                    'No clue what to do with {0}'.format(f.mime_type))
+                print 'No clue what to do with {0}'.format(f.mime_type)
+                # raise ValueError(
+                #     'No clue what to do with {0}'.format(f.mime_type))
 
     item['embed'] = video.embed_code
 
-    if (youtube_embed is not None and 'youtube.com' in video.link
-            and hasattr(video, 'guid')):
+    if (youtube_embed is not None
+        and video.link
+        and is_youtube(video.link)
+        and hasattr(video, 'guid')):
+
+        if youtube_embed in YOUTUBE_EMBED.keys():
+            youtube_embed = YOUTUBE_EMBED[youtube_embed]
 
         guid = video.guid
         if guid:
@@ -356,7 +380,8 @@ def verify_video_data(data, category=None):
 
                     errors.append('"{0}" field must be an int'.format(key))
             elif req['choices'] and data[key] not in req['choices']:
-                errors.append('"{0}" field must be one of {1}'.format(
+                errors.append(
+                    '"{0}" field must be one of {1}'.format(
                         key, req['choices']))
 
         elif req['type'] == 'TextField':
@@ -579,7 +604,7 @@ def scrapevideo(video_url):
             data[field] = dt.isoformat()
 
     data['url'] = video_url
-    if 'youtube.com' in video_url and 'guid' in data and data['guid']:
+    if is_youtube(video_url) and 'guid' in data and data['guid']:
         guid = data['guid'].split('/')[-1]
         data['object_embed_code'] = YOUTUBE_EMBED['object'].format(guid=guid)
         data['iframe_embed_code'] = YOUTUBE_EMBED['iframe'].format(guid=guid)
