@@ -1,7 +1,7 @@
 #######################################################################
 # This file is part of steve.
 #
-# Copyright (C) 2012, 2013 Will Kahn-Greene
+# Copyright (C) 2012-2014 Will Kahn-Greene
 # Licensed under the Simplified BSD License. See LICENSE for full
 # license.
 #######################################################################
@@ -89,10 +89,11 @@ class WebEditRequestHandler(BaseHTTPRequestHandler):
 
     def route_home(self, path):
         config = get_project_config()
-        self.render_response(200, 'home.html', {
+        self.render_response(
+            200, 'home.html', {
                 'title': config.get('project', 'category'),
                 'data_files': load_json_files(config)
-                })
+            })
 
     def route_edit(self, path):
         cfg = get_project_config()
@@ -118,26 +119,29 @@ class WebEditRequestHandler(BaseHTTPRequestHandler):
         for req in reqs:
             key = req['name']
             if key == 'category' and category:
-                fields.append({
+                fields.append(
+                    {
                         'name': req['name'],
                         'value': category
-                        })
+                    })
             else:
-                fields.append({
+                fields.append(
+                    {
                         'name': req['name'],
                         'type': req['type'],
                         'choices': req['choices'],
                         'md': req['md'],
                         'value': data.get(key, '')
-                        })
+                    })
 
-        self.render_response(200, 'edit.html', {
-                'title': 'edit {0}'.format(data['title']),
+        self.render_response(
+            200, 'edit.html', {
+                'title': u'edit {0}'.format(data['title']),
                 'fn': fn,
                 'fields': fields,
                 'prev_fn': prev_fn,
                 'next_fn': next_fn
-                })
+            })
 
     def route_save(self, path):
         cfg = get_project_config()
@@ -151,6 +155,7 @@ class WebEditRequestHandler(BaseHTTPRequestHandler):
 
         for req in reqs:
             key = req['name']
+            print key, req['type']
             if key in form_data:
                 value = None
                 if req['type'] == 'IntegerField':
@@ -166,20 +171,28 @@ class WebEditRequestHandler(BaseHTTPRequestHandler):
                     # TODO: Verify the data format. Maybe if there is
                     # no slug field, we create it from the title?
                     value = form_data[key].value
-                elif req['type'] in ('TextArrayField'):
+                elif req['type'] == 'TextArrayField':
                     # Split the field on carriage returns and drop any
                     # empty strings.
-                    value = [mem.strip()
-                             for mem in form_data[key].value.split('\n')
+                    value = form_data[key].value
+                    value = [mem.strip() for mem in value.split('\n')
                              if mem.strip()]
+                    print repr(value)
 
                 data[key] = value
             else:
                 if req['type'] in ('CharField', 'TextField'):
                     data[key] = ''
+                elif req['type'] == 'TextArrayField':
+                    data[key] = []
 
                 # TODO: What to do about other fields? Set to default?
 
+        # Category is a special case. If it's empty, we should remove
+        # it so verify works well.
+        if 'category' in data and not data['category'].strip():
+            del data['category']
+
         save_json_file(cfg, fn, data)
 
         return self.redirect('/edit/{0}'.format(fn[5:]))
